Crate delegate_registry

Crate delegate_registry 

Macros

all_delegation_is_enabled
Returns true if the all delegation account is valid and enabled, else false.
delegate_registry_program_id
Returns the delegate registry program ID.
delegation_account_is_valid
Returns true if the delegation account is valid, else false.
delegation_account_slice
Returns a slice of the delegation account data. If the slice is out of bounds, returns a zeroed array. This macro does not check if the delegation account is valid.
program_delegation_is_enabled
Returns true if the program delegation account is valid and enabled, else false.
token_delegation_amount
Returns the amount from a token delegation account. If the delegation account is not valid, returns 0.