macro_rules! program_delegation_is_enabled {
($delegation:expr, $rights:expr, $from:expr, $to:expr, $program:expr, $account:expr) => { ... };
}Expand description
Returns true if the program delegation account is valid and enabled, else false.
macro_rules! program_delegation_is_enabled {
($delegation:expr, $rights:expr, $from:expr, $to:expr, $program:expr, $account:expr) => { ... };
}Returns true if the program delegation account is valid and enabled, else false.