Macros
- all_
delegation_ is_ enabled - Returns true if the all delegation account is valid and enabled, else false.
- delegate_
registry_ program_ id - Returns the delegate registry program ID.
- delegation_
account_ is_ valid - Returns true if the delegation account is valid, else false.
- delegation_
account_ slice - Returns a slice of the delegation account data. If the slice is out of bounds, returns a zeroed array. This macro does not check if the delegation account is valid.
- program_
delegation_ is_ enabled - Returns true if the program delegation account is valid and enabled, else false.
- token_
delegation_ amount - Returns the amount from a token delegation account. If the delegation account is not valid, returns 0.